| Title: | bartMachine JARs |
|---|---|
| Description: | These are bartMachine's Java dependency libraries. Note: this package has no functionality of its own and should not be installed as a standalone package without bartMachine. |
| Authors: | Adam Kapelner [aut, cre] (ORCID: 0000-0001-5985-6792), Justin Bleich [aut] |
| Maintainer: | Adam Kapelner <[email protected]> |
| License: | GPL-3 |
| Version: | 1.2.2 |
| Built: | 2026-05-19 10:30:24 UTC |
| Source: | https://github.com/cran/bartMachineJARs |